/* Duck Slaughter by Adam Sepanski
Ported on 1/5/06
Originally created on 7/14/98 using the DigiPen game workshop library

I finally found my old disc and decided I'd port the game onto windows.
I am keeping the game as close to how it was finished as possible. I'm
still using the GP dumb engine.

The game and full source will be hosted at
http://geocities.com/adamskiz/Programming/DuckSlaughter.zip
*/

// to compile make sure to include DDRAW.LIB, DSOUND.LIB,
// DINPUT.LIB, WINMM.LIB, and GPDumb1 and 2 header files in the project.
//I'm pretty sure the gpdumb files need to be in the game directory too.

// INCLUDES ///////////////////////////////////////////////

#define WIN32_LEAN_AND_MEAN 

#include <windows.h>   // include important windows stuff
#include <windowsx.h> 
#include <mmsystem.h>
//comment out for .net #include iostream // include important C/C++ stuff
#include <conio.h>
#include <stdlib.h>
#include <malloc.h>
#include <memory.h>
#include <string.h>
#include <stdarg.h>
#include <stdio.h> 
#include <math.h>
#include <io.h>
#include <fcntl.h>

#include <ddraw.h>  // directX includes
#include <dsound.h>
#define DIRECTINPUT_VERSION 0x0700 //needed to keep the gpdumb engine compatible
#include <dinput.h>
#include "gpdumb1.h" // game library includes
#include "gpdumb2.h"

// DEFINES ////////////////////////////////////////////////

// defines for windows 
#define WINDOW_CLASS_NAME "WINXCLASS"  // class name

#define WINDOW_WIDTH    320   // size of window
#define WINDOW_HEIGHT   240

//game defines
#define INITIAL_DUCK_SPEED 10//Initial speed of duck

//game states
#define GAME_RUNNING 1 //Game is actually playing
#define GAME_LEVELCOMPLETE 2 //Level complete
#define GAME_DEATH 3 //player dies
#define GAME_MAINMENU 4 //main menu screen
#define GAME_INTROSEQUENCE 5 //intro sequence to game

// PROTOTYPES /////////////////////////////////////////////

// game console
int Game_Init(void *parms=NULL);
int Game_Shutdown(void *parms=NULL);
int Game_Main(void *parms=NULL);

bool CollisionCursorOnBob(BOB_PTR cursor,BOB_PTR bob);
void FinishDuckExplosion();
void CreateIntroSequence(int SequenceCount);

// GLOBALS ////////////////////////////////////////////////

HWND main_window_handle           = NULL; // save the window handle
HINSTANCE main_instance           = NULL; // save the instance

BITMAP_IMAGE ToxicBackground_bmp;   // holds the background
BITMAP_IMAGE DeathBG_bmp; //death background
BITMAP_IMAGE MainMenuBG_bmp;//main menu background

//Bob Objects
BOB CursorScanning,CursorLocked;
BOB Duck,DeadDuck;

//sound
int RifleSound=5;//Tennis thwacking sound
int LockedOnBeep=7; //cursor lock on beep

//Game information
int GameState=GAME_INTROSEQUENCE;//General State of Game, game starts with menu

//Misc Globals
bool MouseButtonClicked=false;//checks to see if mouse button has been pressed
bool EnterKeyHitOnce=false;//checks for enter key pressed already
bool BeepSoundPlayed=false;//if beep sound was already played
bool DuckGotShot=false;//if a duck got shot (for animation)

char GameStats[400];//used for storing the score, life, and various other junk
char ScoreText[50];//holds just score
char LevelCompleteText[200];//char for level completion
int TextPositionX=180,TextPositionY=190;//holds text positions for level up screen
char VersionInfo[50]="Ver. 1.0";//version information

int PlayerScore=0;//player's score
int PlayerLife=5;//player life left
int PlayerMisses=0;//player's misses
int CurrentLevel=1;//current level
int KillsThisLevel=0;//how many kills this level (10 advances a level)
int LevelEscapes=0;//how many ducks got away just this level (for score bonus)
int LevelMisses=0;//how many shots missed just this level (for score bonus)

int IntroSequenceCount=0;//frame of intro sequence

// FUNCTIONS //////////////////////////////////////////////

LRESULT CALLBACK WindowProc(HWND hwnd, 
						    UINT msg, 
                            WPARAM wparam, 
                            LPARAM lparam)
{
	// this is the main message handler of the system
	PAINTSTRUCT	ps;		   // used in WM_PAINT
	HDC			hdc;	   // handle to a device context

	// what is the message 
	switch(msg)
		{	
		case WM_CREATE: 
			{
			// do initialization stuff here
			return(0);
			} break;

		case WM_PAINT:
			{
			// start painting
			hdc = BeginPaint(hwnd,&ps);

			// end painting
			EndPaint(hwnd,&ps);
			return(0);
			} break;

		case WM_DESTROY: 
			{
			// kill the application			
			PostQuitMessage(0);
			return(0);
			} break;

		default:break;

		} // end switch

	// process any messages that we didn't take care of 
	return (DefWindowProc(hwnd, msg, wparam, lparam));

} // end WinProc

// WINMAIN ////////////////////////////////////////////////

int WINAPI WinMain(	HINSTANCE hinstance,
					HINSTANCE hprevinstance,
					LPSTR lpcmdline,
					int ncmdshow)
{
	// this is the winmain function

	WNDCLASS winclass;	// this will hold the class we create
	HWND	 hwnd;		// generic window handle
	MSG		 msg;		// generic message

	// first fill in the window class stucture
	winclass.style			= CS_DBLCLKS | CS_OWNDC | 
							CS_HREDRAW | CS_VREDRAW;
	winclass.lpfnWndProc	= WindowProc;
	winclass.cbClsExtra		= 0;
	winclass.cbWndExtra		= 0;
	winclass.hInstance		= hinstance;
	winclass.hIcon			= LoadIcon(NULL, IDI_APPLICATION);
	winclass.hCursor		= LoadCursor(NULL, IDC_ARROW);
	winclass.hbrBackground	= (HBRUSH)GetStockObject(BLACK_BRUSH);
	winclass.lpszMenuName	= NULL; 
	winclass.lpszClassName	= WINDOW_CLASS_NAME;

	// register the window class
	if (!RegisterClass(&winclass))
		return(0);

	// create the window, note the use of WS_POPUP
	if (!(hwnd = CreateWindow(WINDOW_CLASS_NAME, // class
							"WinX Game Console",	 // title
							WS_POPUP| WS_VISIBLE,
					 		0,0,	   // x,y
							WINDOW_WIDTH,  // width
							WINDOW_HEIGHT, // height
							NULL,	   // handle to parent 
							NULL,	   // handle to menu
							hinstance,// instance
							NULL)))	// creation parms
	return(0);

	// save the window handle and instance in a global
	main_window_handle = hwnd;
	main_instance      = hinstance;

	// perform all game console specific initialization
	Game_Init();

	// enter main event loop
	while(1)
		{
		if (PeekMessage(&msg,NULL,0,0,PM_REMOVE))
			{ 
			// test if this is a quit
			if (msg.message == WM_QUIT)
			break;
		
			// translate any accelerator keys
			TranslateMessage(&msg);

			// send the message to the window proc
			DispatchMessage(&msg);
			} // end if
	    
		// main game processing goes here
		Game_Main();

		} // end while

	// shutdown game and release all resources
	Game_Shutdown();

	// return to Windows like this
	return(msg.wParam);

} // end WinMain

//Main Game Functions
int Game_Init(void *parms)
{
	// this function is where you do all the initialization 
	// for your game

	int index; // looping varsIable

	// seed random number generate
	srand(Start_Clock());

	// start up DirectDraw (replace the parms as you desire)
	DD_Init(SCREEN_WIDTH, SCREEN_HEIGHT, SCREEN_BPP);

	// load Toxic Background
	Load_Bitmap_File(&bitmap8bit, "TOXICBG.BMP");
	Create_Bitmap(&ToxicBackground_bmp,0,0,640,480);
	Load_Image_Bitmap(&ToxicBackground_bmp, &bitmap8bit,0,0,BITMAP_EXTRACT_MODE_ABS);
	Set_Palette(bitmap8bit.palette);
	Unload_Bitmap_File(&bitmap8bit);

	//load death bg
	Load_Bitmap_File(&bitmap8bit, "death.BMP");
	Create_Bitmap(&DeathBG_bmp,0,0,640,480);
	Load_Image_Bitmap(&DeathBG_bmp, &bitmap8bit,0,0,BITMAP_EXTRACT_MODE_ABS);
	Set_Palette(bitmap8bit.palette);
	Unload_Bitmap_File(&bitmap8bit);

	//load main menu bg
	Load_Bitmap_File(&bitmap8bit, "start.BMP");
	Create_Bitmap(&MainMenuBG_bmp,0,0,640,480);
	Load_Image_Bitmap(&MainMenuBG_bmp, &bitmap8bit,0,0,BITMAP_EXTRACT_MODE_ABS);
	Set_Palette(bitmap8bit.palette);
	Unload_Bitmap_File(&bitmap8bit);

	//Load Scanning Cursor
	// load the bitmaps
	Load_Bitmap_File(&bitmap8bit, "Scanning.BMP");
	// create bob
	Create_BOB(&CursorScanning,0,0,64,64,4,BOB_ATTR_MULTI_FRAME | BOB_ATTR_VISIBLE,DDSCAPS_SYSTEMMEMORY);
	// set animation speed
	Set_Anim_Speed_BOB(&CursorScanning, 3);
	// set motion speed
	Set_Vel_BOB(&CursorScanning,0,0);
	// set position
	Set_Pos_BOB(&CursorScanning, 200, 200);
	// load the bob in
	for (index=0; index < 4; index++)
	{Load_Frame_BOB(&CursorScanning, &bitmap8bit, index, 0, index, BITMAP_EXTRACT_MODE_CELL);}
	// unload bitmap image
	Unload_Bitmap_File(&bitmap8bit);

	//Load Locked on Cursor
	Load_Bitmap_File(&bitmap8bit, "Lockedon.bmp");
	Create_BOB(&CursorLocked,0,0,64,64,7,BOB_ATTR_MULTI_FRAME | BOB_ATTR_VISIBLE,DDSCAPS_SYSTEMMEMORY);
	Set_Anim_Speed_BOB(&CursorLocked,2);
	Set_Vel_BOB(&CursorLocked,0,0);
	Set_Pos_BOB(&CursorLocked,100,100);
	for(index=0;index<7;index++)
	{Load_Frame_BOB(&CursorLocked,&bitmap8bit,index,0,index,BITMAP_EXTRACT_MODE_CELL);}
	Unload_Bitmap_File(&bitmap8bit);

	//Load Duck
	Load_Bitmap_File(&bitmap8bit, "Duck.bmp");
	Create_BOB(&Duck,0,0,128,64,6,BOB_ATTR_MULTI_FRAME | BOB_ATTR_VISIBLE,DDSCAPS_SYSTEMMEMORY);
	Set_Anim_Speed_BOB(&Duck,3);
	Set_Vel_BOB(&Duck,-(INITIAL_DUCK_SPEED),0);
	Set_Pos_BOB(&Duck,screen_width,rand()%(480-Duck.height));
	for(index=0;index<6;index++)
	{Load_Frame_BOB(&Duck,&bitmap8bit,index,0,index,BITMAP_EXTRACT_MODE_CELL);}
	Unload_Bitmap_File(&bitmap8bit);

	//load dead duck
	Load_Bitmap_File(&bitmap8bit, "deadduck.bmp");
	Create_BOB(&DeadDuck,0,0,128,64,3,BOB_ATTR_MULTI_FRAME | BOB_ATTR_VISIBLE,DDSCAPS_SYSTEMMEMORY);
	Set_Anim_Speed_BOB(&DeadDuck,3);
	Set_Vel_BOB(&DeadDuck,0,0);
	Set_Pos_BOB(&DeadDuck,0,0);
	for(index=0;index<3;index++)
	{Load_Frame_BOB(&DeadDuck,&bitmap8bit,index,0,index,BITMAP_EXTRACT_MODE_CELL);}
	Unload_Bitmap_File(&bitmap8bit);

	// initialize directinput
	DInput_Init();

	// acquire the keyboard only
	DI_Init_Keyboard();
	DI_Init_Mouse();

	// initilize DirectSound
	DSound_Init();

	// load sounds
	RifleSound=Load_WAV("Rifle.WAV");//Rifle Sound
	LockedOnBeep=Load_WAV("Beep.wav");//cursor lock on beep

	//the sounds needed to be loaded at a specific frequency.  setting the freq manually fixes
	//the goofy playbacks
	//make the ball sound not sound retarded
	//Set_Sound_Freq(TennisThwack1,8000);

	// set clipping rectangle to screen extents so objects dont
	// mess up at edges
	RECT screen_rect = {0,0,screen_width,screen_height};
	lpddclipper = DD_Attach_Clipper(lpddsback,1,&screen_rect);

	// hide the mouse
	ShowCursor(FALSE);

	// return success
	return(1);

} // end Game_Init

///////////////////////////////////////////////////////////

int Game_Shutdown(void *parms)
{
	// this function is where you shutdown your game and
	// release all resources that you allocated

	// shut everything down

	// kill all the bobs
	Destroy_BOB2(&CursorScanning);
	Destroy_BOB2(&CursorLocked);
	Destroy_BOB2(&Duck);
	Destroy_BOB2(&DeadDuck);

	// shutdown directdraw last
	DD_Shutdown();

	// now directsound
	Stop_All_Sounds();
	DSound_Shutdown();

	// shut down directinput
	DInput_Shutdown();

	// return success
	return(1);

} // end Game_Shutdown

//////////////////////////////////////////////////////////

int Game_Main(void *parms)
{
	//main game loop

	bool CursorCollision;//created so the function only has to run once.
	////bonuses for level completion
	int EscapeBonus=0;
	int MissBonus=0;
	int LevelBonus=100;


	// start the timing clock
	Start_Clock();

	// clear the drawing surface
	DD_Fill_Surface(lpddsback, 0);

	// lock back buffer and copy background into it
	DD_Lock_Back_Surface();

	// draw background
	//if death, draw death bg
	if(GameState==GAME_DEATH)
	{
		Draw_Bitmap(&DeathBG_bmp,back_buffer,back_lpitch,0);
	}
	//if main menu, draw main menu bg
	else if (GameState==GAME_MAINMENU)
	{
		Draw_Bitmap(&MainMenuBG_bmp,back_buffer,back_lpitch,0);
	}
	else
	{Draw_Bitmap(&ToxicBackground_bmp, back_buffer, back_lpitch,0);}

	// unlock surface
	DD_Unlock_Back_Surface();

	// read keyboard
	DI_Read_Keyboard();
	DI_Read_Mouse();

	//Reset Key Variables
	/* these variables are needed because during the game loop if a key is pressed it will
	continue to fire through multiple loops.  Therefor, most of the key pressed if loops will
	test to see if the key has already been pressed, and the variable will only reset if the 
	game has gone through a loop with the key up.*/
	if(!mouse_state.rgbButtons[0])
	{
		MouseButtonClicked=false;
	}
	if(!keyboard_state[DIK_RETURN])
	{
		EnterKeyHitOnce=false;
	}
	//main game state switch
	//this is the main workhorse of the program, it reads in the state of the game and decides
	//what to render based on that
	switch (GameState)
	{
		case GAME_RUNNING:
			//set cursor to move with the mouse
			Set_Vel_BOB(&CursorScanning,mouse_state.lX*.75,mouse_state.lY*.75);
			Move_BOB(&CursorScanning);
			Move_BOB(&Duck);

			/*//FOR DEBUGGING AND DEMO PURPOSES ONLY!!!, move duck with keys
			if(keyboard_state[DIK_RIGHT])
			{
				Set_Vel_BOB(&Duck,INITIAL_DUCK_SPEED,Duck.yv);
				Move_BOB(&Duck);
			}
			if(keyboard_state[DIK_LEFT])
			{
				Set_Vel_BOB(&Duck,-INITIAL_DUCK_SPEED,Duck.yv);
				Move_BOB(&Duck);
			}
			if(keyboard_state[DIK_UP])
			{
				Set_Vel_BOB(&Duck,Duck.xv,-INITIAL_DUCK_SPEED);
				Move_BOB(&Duck);
			}
			if(keyboard_state[DIK_DOWN])
			{
				Set_Vel_BOB(&Duck,Duck.xv,INITIAL_DUCK_SPEED);
				Move_BOB(&Duck);
			}
			Set_Vel_BOB(&Duck,0,0);
			//////end of debugging,demo code*/


			//collision detection
			//Cursor
			//cursor on background
			if(CursorScanning.cx>=screen_width)
			{Set_Pos_BOB(&CursorScanning,screen_width-(CursorScanning.width/2),CursorScanning.y);}
			if(CursorScanning.cx<=0)
			{Set_Pos_BOB(&CursorScanning,0-(CursorScanning.width/2),CursorScanning.y);}
			if(CursorScanning.cy>=screen_height)
			{Set_Pos_BOB(&CursorScanning,CursorScanning.x,screen_height-(CursorScanning.height/2));}
			if(CursorScanning.cy<=0)
			{Set_Pos_BOB(&CursorScanning,CursorScanning.x,0-(CursorScanning.height/2));}
			//Duck with left wall (duck got away)
			if(Duck.rightline<=0)
			{
				//lose a life, and an escape for the level
				PlayerLife--;
				LevelEscapes--;
				//reset duck position
				Set_Pos_BOB(&Duck,screen_width,rand()%(480-Duck.height));
			}
			
			//if the duck was shot, play the dead duck animation
			//this helped the proper showing of the duck dying sequence
			if(DuckGotShot)
			{
				Animate_BOB(&DeadDuck);
				Draw_BOB(&DeadDuck,lpddsback);
				
				//stop showing the dead duck bob when the animation is over
				if(DeadDuck.curr_frame==2)
				{DuckGotShot=false;}
			}

			//is the cursor on a duck?
			CursorCollision=CollisionCursorOnBob(&CursorScanning,&Duck);
			
			//if cursor not on duck and mouse is clicked (miss)
			if (!CursorCollision && mouse_state.rgbButtons[0] && !MouseButtonClicked)
			{
				//play shooting sound
				Play_Sound(RifleSound);
				MouseButtonClicked=true;
				//player misses a shot and for the level
				PlayerMisses++;
				LevelMisses++;
				//player loses points
				PlayerScore-=20;
				
				
				Animate_BOB(&Duck);
				Draw_BOB(&Duck,lpddsback);
				Animate_BOB(&CursorScanning);
				Draw_BOB(&CursorScanning,lpddsback);
			}
			//if cursor isn't on duck, draw duck, draw scanning cursor
			else if(!CursorCollision)
			{
				//if the cursor moves off the duck, stop the beep sound
				Stop_Sound(LockedOnBeep);
				//and set the sound to not played
				BeepSoundPlayed=false;

				Animate_BOB(&Duck);
				Draw_BOB(&Duck,lpddsback);
				Animate_BOB(&CursorScanning);
				Draw_BOB(&CursorScanning,lpddsback);
			}
			//if cursor's on duck and mouse button is up
			else if(CursorCollision && !mouse_state.rgbButtons[0])
			{
				//set the locked cursor at the same position as scanning cursor
				Set_Pos_BOB(&CursorLocked,CursorScanning.x,CursorScanning.y);
				
				//if beep sound hasn't been played, play it
				if(!BeepSoundPlayed)
				{
					//loop continuously while on duck
					Play_Sound(LockedOnBeep,DSBPLAY_LOOPING);
					BeepSoundPlayed=true;
				}
				
				//draw duck then locked cursor
				Animate_BOB(&Duck);
				Draw_BOB(&Duck,lpddsback);
				Animate_BOB(&CursorLocked);
				Draw_BOB(&CursorLocked,lpddsback);
			}
			//if cursor's on duck, mouse button is down (hit)
			else if(CursorCollision && mouse_state.rgbButtons[0] && !MouseButtonClicked)
			{
				//set locked cursor to mouse position
				Set_Pos_BOB(&CursorLocked,CursorScanning.x,CursorScanning.y);
				//set duck is dead bool to true
				DuckGotShot=true;
				//player gets points and his kills to the next level goes up
				PlayerScore+=50;
				KillsThisLevel++;

				//set dead duck position to where duck was hit
				Set_Pos_BOB(&DeadDuck,Duck.x,Duck.y);
				//resets dead duck animation (defensive)
				DeadDuck.curr_frame=0;

				//reset duck position
				Set_Pos_BOB(&Duck,screen_width,rand()%(480-Duck.height));

				//draw locked cursor
				Animate_BOB(&CursorLocked);
				Draw_BOB(&CursorLocked,lpddsback);
				//play rifle sound
				Play_Sound(RifleSound);
				//set mouse button to clicked
				MouseButtonClicked=true;
			}
			//defensive (anything that didn't get caught)
			else
			{
				Animate_BOB(&Duck);
				Draw_BOB(&Duck,lpddsback);
				Animate_BOB(&CursorScanning);
				Draw_BOB(&CursorScanning,lpddsback);
			}
			
			//don't let score go negative
			if(PlayerScore<0)
			{PlayerScore=0;}
			
			//display score and game information
			sprintf(GameStats,"Score: %d Life: %d Level: %d Misses: %d",PlayerScore,PlayerLife,CurrentLevel,PlayerMisses);
			Draw_Text_GDI(GameStats,0,0,RGB(0,0,0),lpddsback);
			
			if(KillsThisLevel==5)
			{
				//stop the beeping from going while the level is changing
				Stop_Sound(LockedOnBeep);
				//switch to level complete screen
				GameState=GAME_LEVELCOMPLETE;
				//level goes up and reset to next level variable
				CurrentLevel++;
				KillsThisLevel=0;
				//a function to show the remainder of the duck death sequence so it doesn't
				//happen at the beginning of the next level
				FinishDuckExplosion();
				//don't show duck dying sequence, we will do it manually
				DuckGotShot=false;
			}
			if(PlayerLife==0)
			{
				//player dies
				GameState=GAME_DEATH;
			}

			break;
		
		case GAME_LEVELCOMPLETE:
			//increase the duck speed based on level
			Set_Vel_BOB(&Duck,-(INITIAL_DUCK_SPEED+(CurrentLevel*2)),0);

			//draws score in upper left hand
			sprintf(ScoreText,"Score: %d",PlayerScore);
			Draw_Text_GDI(ScoreText,0,0,RGB(0,0,0),lpddsback);

			//show some text about level
			sprintf(LevelCompleteText,"Congratulations! You Completed Level %d!",CurrentLevel-1);
			Draw_Text_GDI(LevelCompleteText,TextPositionX,TextPositionY,RGB(255,255,0),lpddsback);
			
			//no escape bonus (no ducks got away)
			if(LevelEscapes==0)
			{
				EscapeBonus=100;
				Draw_Text_GDI("No Escape Bonus! +100 Points!",TextPositionX+30,TextPositionY+30,RGB(255,0,0),lpddsback);
			}
			//no miss bonus (shot fired but missed)
			if(LevelMisses==0)
			{
				MissBonus=200;
				Draw_Text_GDI("Sharp Shooting Bonus! +200 Points!", TextPositionX+10,TextPositionY+60,RGB(255,0,0),lpddsback);
			}
			//bonus for completing level
			Draw_Text_GDI("Level Complete Bonus! +100 Points! +1 Life!",TextPositionX-10,TextPositionY+90,RGB(255,0,0),lpddsback);
			Draw_Text_GDI("Hit Space To Continue",TextPositionX+60,TextPositionY+120,RGB(50,255,255),lpddsback);

			//go to next level on spacebar
			if(keyboard_state[DIK_SPACE])
			{
				GameState=GAME_RUNNING;
				//add bonuses to score
				PlayerScore+=EscapeBonus+MissBonus+LevelBonus;
				//add a life for beating a level
				PlayerLife+=1;
				//reset some variables
				LevelMisses=0;
				LevelEscapes=0;
			}
			break;

		//player dies
		case GAME_DEATH:
			//show their score
			sprintf(ScoreText,"Score: %d",PlayerScore);
			Draw_Text_GDI(ScoreText,10,10,RGB(255,255,0),lpddsback);

			//if enter is pressed go to main menu
			if(keyboard_state[DIK_RETURN] && !EnterKeyHitOnce)
			{
				GameState=GAME_MAINMENU;
				EnterKeyHitOnce=true;
			}

			break;

		//main menu screen
		case GAME_MAINMENU:
			Draw_Text_GDI(VersionInfo,550,450,RGB(0,0,0),lpddsback);
			//if enter is hit run game and reset all variables
			if(keyboard_state[DIK_RETURN] && !EnterKeyHitOnce )
			{
				//play game but reset all game variables first
				GameState=GAME_RUNNING;
				PlayerScore=0;
				PlayerLife=5;
				PlayerMisses=0;
				LevelMisses=0;
				LevelEscapes=0;
				KillsThisLevel=0;
				CurrentLevel=1;
				Set_Vel_BOB(&Duck,-(INITIAL_DUCK_SPEED),0);
				Set_Pos_BOB(&Duck,screen_width,rand()%480-Duck.height);

				EnterKeyHitOnce=true;
			}
		break;

		//game intro sequence
		case GAME_INTROSEQUENCE:
			//thought it would be best to call a function so there's not a whole bunch of
			//hard coded stuff in the main game loop
			CreateIntroSequence(IntroSequenceCount);
			
			//sequence frame increases
			IntroSequenceCount++;

			//at end of sequence go to main menu and reset intro
			if(IntroSequenceCount==100)
			{
				GameState=GAME_MAINMENU;
				IntroSequenceCount=0;
			}
			break;

		default:
			//something would be amiss here
			break;
	}
	
	// flip the surfaces
	DD_Flip();

	// sync to static fps... 1/30sec or 30 fps = 33 ms
	Wait_Clock(33);

	// check if user is trying to exit
	if (keyboard_state[DIK_ESCAPE])
		{
				PostMessage(main_window_handle, WM_DESTROY,0,0);
				// stop all sounds
				Stop_All_Sounds();

				// do a screen transition
				Screen_Transitions(SCREEN_DARKNESS,NULL,0);
		} // end if

	// return success
	return(1);

} // end Game_Main

//////////////////////////////////////////////////////////
//additional functions

//this checks to see fi the cursor is over the duck
bool CollisionCursorOnBob(BOB_PTR cursor, BOB_PTR bob)
{
	//if the cursor is inside the duck bob's coordinates return true
	if(cursor->cx > bob->leftline && cursor->cx < bob->rightline-10 &&
cursor->cy > bob->topline+20 && cursor->cy < bob->bottomline)
	{return true;}
	//else return false
	return false;
}

//finishes duck explosion, used right before a level change
void FinishDuckExplosion()
{
	Animate_BOB(&DeadDuck);
	Draw_BOB(&DeadDuck,lpddsback);
	Animate_BOB(&DeadDuck);
	Draw_BOB(&DeadDuck,lpddsback);
	Animate_BOB(&DeadDuck);
	Draw_BOB(&DeadDuck,lpddsback);
}

//function for the entire intro sequence
void CreateIntroSequence(int SequenceCount)
{
	//let us catch up
	if(SequenceCount==0)
	{
		Sleep(500);
	}
	//set cursor position and draw
	else if(SequenceCount>=2 && SequenceCount<10)
	{
		Set_Pos_BOB(&CursorScanning,310,420);
		Set_Vel_BOB(&CursorScanning,0,-6);
		Animate_BOB(&CursorScanning);
		Draw_BOB(&CursorScanning,lpddsback);
	}

	//set duck position and draw
	else if(SequenceCount==10)
	{
		Set_Pos_BOB(&Duck,screen_width,200);
		Set_Vel_BOB(&Duck,-9,0);

		Move_BOB(&Duck);

		Animate_BOB(&Duck);
		Draw_BOB(&Duck,lpddsback);
		Animate_BOB(&CursorScanning);
		Draw_BOB(&CursorScanning,lpddsback);
	}
	//move duck but hold off on moving cursor
	else if (SequenceCount>10 && SequenceCount<14)
	{
		Move_BOB(&Duck);

		Animate_BOB(&Duck);
		Draw_BOB(&Duck,lpddsback);
		Animate_BOB(&CursorScanning);
		Draw_BOB(&CursorScanning,lpddsback);
	}
	//move duck left and cursor up
	else if (SequenceCount>=14 && SequenceCount<48)
	{
		Move_BOB(&Duck);
		Move_BOB(&CursorScanning);

		Animate_BOB(&Duck);
		Draw_BOB(&Duck,lpddsback);
		Animate_BOB(&CursorScanning);
		Draw_BOB(&CursorScanning,lpddsback);
	}
	//switch to locked on cursor, move it with duck, and play locked on beep
	else if(SequenceCount==48)
	{
		Set_Pos_BOB(&CursorLocked,CursorScanning.x+5,CursorScanning.y-5);
		Set_Vel_BOB(&CursorLocked,-7,0);
		Set_Vel_BOB(&Duck,-7,0);
		
		Move_BOB(&Duck);
		Move_BOB(&CursorLocked);

		Animate_BOB(&Duck);
		Animate_BOB(&CursorLocked);
		Draw_BOB(&Duck,lpddsback);
		Draw_BOB(&CursorLocked,lpddsback);

		Play_Sound(LockedOnBeep,DSBPLAY_LOOPING);
	}
	//move locked on cursor and duck left
	else if(SequenceCount>48 && SequenceCount<75)
	{
		Move_BOB(&Duck);
		Move_BOB(&CursorLocked);

		Animate_BOB(&Duck);
		Animate_BOB(&CursorLocked);
		Draw_BOB(&Duck,lpddsback);
		Draw_BOB(&CursorLocked,lpddsback);
	}
	//stop beep and play rifle shooting
	else if (SequenceCount==75)
	{
		Stop_Sound(LockedOnBeep);
		Play_Sound(RifleSound);
	}
	//play dead duck animation
	else if (SequenceCount==76)
	{
		Set_Pos_BOB(&DeadDuck,Duck.x,Duck.y);
		Animate_BOB(&DeadDuck);
		Draw_BOB(&DeadDuck,lpddsback);
	}
	//finish dead duck animation
	else if(SequenceCount>76 && SequenceCount<80)
	{
		Animate_BOB(&DeadDuck);
		Draw_BOB(&DeadDuck,lpddsback);
	}

}
